# hesseflux

hesseflux provides functions used in the processing and
post-processing of the Eddy covariance flux data of the
ICOS ecosystem site FR-Hes.

Created May 2020 by Matthias Cuntz.

It is distributed under the MIT License (see LICENSE file and below).

Copyright (c) 2009-2020 Matthias Cuntz

## Main Authors

- [Matthias Cuntz](https://github.com/mcuntz), E-mail: mc (at) macu (dot) de

## Contributing Authors

- [Arndt Piayda](https://github.com/peterchenchenchen) 
- Tino Rau
- [Juliane Mai](https://github.com/julemai)
- [Sebastian Müller](https://github.com/MuellerSeb)
